{% load static %}
<!DOCTYPE html>
<html lang="en" html data-theme="dark">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>style test</title>
    <link rel="stylesheet" href="{% static 'nutrition/css/styles.css' %}">
<!-- <link href="https://cdn.jsdelivr.net/npm/daisyui@4.12.10/dist/full.min.css" rel="stylesheet" type="text/css" />
<script src="https://cdn.tailwindcss.com"></script> -->
</head>
<body>
    <!-- <div class="bg-secondary text-secondary-content p-4 text-center"> -->
    <div class="bg-accent text-accent-content">
        <!-- <h2 class="text-lg font-bold">some text</h2> -->
        some text
    </div>
    </body>
</html>


