{% extends 'django_nutrition/base-simple.html' %}


{% block body_content %}
  <header>
{% include 'django_nutrition/header.html' %}
  </header>
  <main>
{% block content %}{% endblock %}
  </main>
{% endblock %}
